@@ -29,7 +29,11 @@ class XrayScan(ToolGateway):
         if installed.returncode == 1:
             command = ["chmod", "+x", prefix]
             try:
-                url = f"https://releases.jfrog.io/artifactory/jfrog-cli/v2-jf/{version}/jfrog-cli-linux-amd64/jf"
+                architecture = platform.machine()
+                if architecture == "aarch64":
+                    url = f"https://releases.jfrog.io/artifactory/jfrog-cli/v2-jf/{version}/jfrog-cli-linux-arm64/jf"
+                else:
+                    url = f"https://releases.jfrog.io/artifactory/jfrog-cli/v2-jf/{version}/jfrog-cli-linux-amd64/jf"
                 response = requests.get(url, allow_redirects=True)
                 with open(prefix, "wb") as archivo:
                     archivo.write(response.content)
