@@ -7,9 +7,14 @@ from devsecops_engine_tools.engine_sca.engine_dependencies.src.domain.usecases.s
 from devsecops_engine_tools.engine_sca.engine_dependencies.src.domain.usecases.handle_remote_config_patterns import (
     HandleRemoteConfigPatterns,
 )
+from devsecops_engine_tools.engine_core.src.domain.model.gateway.devops_platform_gateway import (
+    DevopsPlatformGateway,
+)
+from devsecops_engine_tools.engine_core.src.domain.model.gateway.sbom_manager import (
+    SbomManagerGateway,
+)
 
 import os
-import sys
 
 from devsecops_engine_tools.engine_utilities.utils.logger_info import MyLogger
 from devsecops_engine_tools.engine_utilities import settings
@@ -18,7 +23,13 @@ logger = MyLogger.__call__(**settings.SETTING_LOGGER).get_logger()
 
 
 def init_engine_dependencies(
-    tool_run, tool_remote, tool_deserializator, dict_args, secret_tool, tool
+    tool_run,
+    tool_remote: DevopsPlatformGateway,
+    tool_deserializator,
+    dict_args,
+    secret_tool,
+    config_tool,
+    tool_sbom: SbomManagerGateway,
 ):
     remote_config = tool_remote.get_remote_config(
         dict_args["remote_config_repo"],
@@ -40,7 +51,14 @@ def init_engine_dependencies(
 
     dependencies_scanned = None
     deserialized = []
-    input_core = SetInputCore(remote_config, exclusions, pipeline_name, tool)
+    sbom_components = None
+    config_sbom = config_tool["SBOM_MANAGER"]
+    input_core = SetInputCore(
+        remote_config,
+        exclusions,
+        pipeline_name,
+        config_tool["ENGINE_DEPENDENCIES"]["TOOL"],
+    )
 
     if scan_flag and not (skip_flag):
         to_scan = dict_args["folder_path"] if dict_args["folder_path"] else os.getcwd()
@@ -55,6 +73,15 @@ def init_engine_dependencies(
                 to_scan,
                 secret_tool,
             )
+            if config_sbom["ENABLED"] and any(
+                branch in str(tool_remote.get_variable("branch_tag"))
+                for branch in config_sbom["BRANCH_FILTER"]
+            ):
+                sbom_components = tool_sbom.get_components(
+                    to_scan,
+                    config_sbom,
+                    pipeline_name
+                )
             dependencies_scanned = dependencies_sca_scan.process()
             deserialized = (
                 dependencies_sca_scan.deserializator(dependencies_scanned)
@@ -69,4 +96,4 @@ def init_engine_dependencies(
 
     core_input = input_core.set_input_core(dependencies_scanned)
 
-    return deserialized, core_input
+    return deserialized, core_input, sbom_components
