@@ -26,19 +26,28 @@ def init_report_sonar(
         args["remote_config_repo"], "/engine_core/ConfigTool.json", args["remote_config_branch"]
     )
     report_config_tool = devops_platform_gateway.get_remote_config(
-        args["remote_config_repo"], "/report_sonar/ConfigTool.json"
+        args["remote_config_repo"], "/report_sonar/ConfigTool.json", args["remote_config_branch"]
     )
+    excluded_pipelines = devops_platform_gateway.get_remote_config(
+        args["remote_config_repo"], "/report_sonar/Exclusions.json", args["remote_config_branch"]
+    )
+    
     Printers.print_logo_tool(config_tool["BANNER"])
 
     pipeline_name = devops_platform_gateway.get_variable("pipeline_name")
     branch = devops_platform_gateway.get_variable("branch_tag")
+
     is_valid_pipeline = not re.match(
-        report_config_tool["IGNORE_SEARCH_PATTERN"], pipeline_name, re.IGNORECASE
-    )
+        report_config_tool["IGNORE_SEARCH_PATTERN"], 
+        pipeline_name, 
+        re.IGNORECASE
+    ) and pipeline_name not in excluded_pipelines
+    
     is_valid_branch = any(
         target_branch in str(branch)
         for target_branch in report_config_tool["TARGET_BRANCHES"]
     )
+
     is_enabled = config_tool["REPORT_SONAR"]["ENABLED"]
 
     if is_enabled and is_valid_pipeline and is_valid_branch:
